==> screem_0.12.1.orig.tar.gz: screem-0.12.1/include/screem-session.h <==
#ifndef SCREEM_SESSION_H
#define SCREEM_SESSION_H

#include <glib-object.h>
#include <gtk/gtkwidget.h>

#define SCREEM_TYPE_SESSION            (screem_session_get_type ())
#define SCREEM_SESSION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), SCREEM_TYPE_SESSION, ScreemSession))
#define SCREEM_SESSION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), SCREEM_TYPE_SESSION, ScreemSessionClass))
#define SCREEM_IS_SESSION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SCREEM_TYPE_SESSION))

typedef struct ScreemSessionPrivate ScreemSessionPrivate;

#define SESSION_GNOME "type:session_gnome"
#define SESSION_LAST "type:session_last"

typedef struct {
	GObject parent;

	ScreemSessionPrivate *priv;
} ScreemSession;

typedef struct {
	GObjectClass parent_class;

} ScreemSessionClass;

GType screem_session_get_type( void );
ScreemSession* screem_session_new( GObject *app );

void screem_session_load( ScreemSession *session,
			  const gchar *filename );
gboolean screem_session_save( ScreemSession *session, const gchar *filename );

void screem_session_set_dialog( ScreemSession *session, 
		const gchar *name, gint x, gint y, gint w, gint h );
gboolean screem_session_get_dialog( ScreemSession *session, 
		const gchar *name, gint *x, gint *y, gint *w, gint *h );

/* util functions for screem_session_get/set_dialog() */
void screem_session_restore_dialog( ScreemSession *session,
		GtkWidget *widget );
void screem_session_store_dialog( ScreemSession *Session,
		GtkWidget *widget );

#endif

==> screem-0.16.1.tar.gz: screem-0.16.1/include/screem-session.h <==
#ifndef SCREEM_SESSION_H
#define SCREEM_SESSION_H

#include <glib-object.h>
#include <gtk/gtkwidget.h>

#define SCREEM_TYPE_SESSION            (screem_session_get_type ())
#define SCREEM_SESSION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), SCREEM_TYPE_SESSION, ScreemSession))
#define SCREEM_SESSION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), SCREEM_TYPE_SESSION, ScreemSessionClass))
#define SCREEM_IS_SESSION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SCREEM_TYPE_SESSION))

typedef struct ScreemSessionPrivate ScreemSessionPrivate;

#define SESSION_GNOME "type:session_gnome"
#define SESSION_LAST "type:session_last"

typedef struct {
	GObject parent;

	ScreemSessionPrivate *priv;
} ScreemSession;

typedef struct {
	GObjectClass parent_class;

} ScreemSessionClass;

GType screem_session_get_type( void );
ScreemSession* screem_session_new( GObject *app );

void screem_session_load( ScreemSession *session,
			  const gchar *filename );
gboolean screem_session_save( ScreemSession *session, const gchar *filename );

void screem_session_set_dialog( ScreemSession *session, 
		const gchar *name, gint x, gint y, gint w, gint h );
gboolean screem_session_get_dialog( ScreemSession *session, 
		const gchar *name, gint *x, gint *y, gint *w, gint *h );

/* util functions for screem_session_get/set_dialog() */
void screem_session_restore_dialog( ScreemSession *session,
		GtkWidget *widget );
void screem_session_store_dialog( ScreemSession *Session,
		GtkWidget *widget );


void screem_session_site_set_expanded( ScreemSession *session,
		const gchar *name, const gchar *uri,
		gboolean status );
gboolean screem_session_site_get_expanded( ScreemSession *session,
		const gchar *name, const gchar *uri );

#endif
